class Color():
    def __init__(self):
        pass


class LinearGradient():
    def __init__(self):
        pass


class RadialGradient():
    def __init__(self):
        pass
